@@ -303,7 +303,6 @@ impl<'a> Backup {
         scheduler: &mut JobScheduler,
         schedule: cron::Schedule,
     ) -> Result<Uuid, JobSchedulerError> {
-
         scheduler.add(
             Job::new_async(schedule.to_string().as_str(), move |_uuid, _js| {
                 let inst = self.clone();
@@ -338,7 +337,7 @@ impl<'a> Backup {
                     // If the local_files list contains a single file, the upload should be in the form:
                     // /remote/prefix/filename
                     // even if the local file is in /local/path/in/folder/filename
-                    let mut single_file = local_files.len() <= 1;
+                    let mut single_file = local_files.len() == 1;
 
                     // If the local_files list is a list of multiple files, we suppose these files all
                     // share the same root. To find the root we can simply find the shortest string.
